@@ -2,8 +2,6 @@ package Ruby::Run;
 
 use strict;
 use warnings;
-use Ruby qw(rb_eval);
-
 
 use Filter::Util::Call;
 
@@ -18,7 +16,7 @@ sub filter{
 	return 0 if $self->{eof};
 
 	$_ = <<'HEAD' if $self->{line}++ == 0;
-Ruby::Run::rb_eval(<<'[RUBY]', __PACKAGE__, __FILE__, __LINE__);
+require Ruby;Ruby::rb_eval(<<'[RUBY]', __PACKAGE__, __FILE__, __LINE__-3);
 HEAD
 
 	my $status = filter_read();
@@ -35,11 +33,19 @@ __END__
 
 =head1 NAME
 
-Ruby::Run - Run a ruby script
+Ruby::Run - Run Ruby script
 
 =head1 SYNOPSIS
 
-	perl -MRuby::Run foo.rb
+	use Ruby::Run;
+
+	# write Ruby code
+
+	def add(x, y)
+		x + y
+	end
+
+	p add(1, 2) # => 3
 
 =head1 SEE ALSO
 
